utils

package module
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2021 License: MIT Imports: 2 Imported by: 0

README

utils-go

pkg goreportcard workflow codecov

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrEnvironmentVariableNotSet = errors.New("environment variable not set")
)

Functions

This section is empty.

Types

type EnvUtils

type EnvUtils struct{}

EnvUtils is an empty structure that is prepared only for creating methods.

var Env EnvUtils

Env is an entity that allows the methods of IntSliceUtils to be executed from outside the package without initializing IntSliceUtils.

func (EnvUtils) Get added in v1.0.2

func (EnvUtils) Get(key string) (value string, err error)

func (EnvUtils) GetOrDefault

func (EnvUtils) GetOrDefault(key, defaultValue string) (value string)

GetOrDefault returns the value of the environment variable `key` if it is set, or `defaultValue` if it is not set.

type SliceUtils

type SliceUtils struct{}

SliceUtils is an empty structure that is prepared only for creating methods.

var Slice SliceUtils

Slice is an entity that allows the methods of IntSliceUtils to be executed from outside the package without initializing IntSliceUtils.

func (SliceUtils) ContainsInt

func (SliceUtils) ContainsInt(slice []int, value int) bool

ContainsInt returns whether or not the passed slice contains the passed value.

func (SliceUtils) ContainsString

func (SliceUtils) ContainsString(slice []string, value string) bool

ContainsString returns whether or not the passed slice contains the passed value.

Jump to