Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EnvUtils ¶
type EnvUtils struct{}
EnvUtils is an empty structure that is prepared only for creating methods.
var Env EnvUtils
Env is an entity that allows the methods of IntSliceUtils to be executed from outside the package without initializing IntSliceUtils.
func (EnvUtils) GetOrDefault ¶
GetOrDefault returns the value of the environment variable `key` if it is set, or `defaultValue` if it is not set.
type SliceUtils ¶
type SliceUtils struct{}
SliceUtils is an empty structure that is prepared only for creating methods.
var Slice SliceUtils
Slice is an entity that allows the methods of IntSliceUtils to be executed from outside the package without initializing IntSliceUtils.
func (SliceUtils) ContainsInt ¶
func (SliceUtils) ContainsInt(slice []int, value int) bool
ContainsInt returns whether or not the passed slice contains the passed value.
func (SliceUtils) ContainsString ¶
func (SliceUtils) ContainsString(slice []string, value string) bool
ContainsString returns whether or not the passed slice contains the passed value.